@@ -61,5 +61,5 @@ class MysqlConnector(DatabaseConnector):
     def get_table_data_query(self, query):
         return f"SELECT * FROM ({query}) base_query"
 
-    def get_table_data_with_paging_query(self, query, order_row, start, end):
-        return f"SELECT * FROM ({query} order by `{order_row}`) ordered_query limit {end - start} offset {start}"
+    def get_table_data_with_paging_query(self, query, order_column, start, end):
+        return f"SELECT * FROM (select * from ({query}) order by `{order_column}`) ordered_query limit {end - start} offset {start}"
