@@ -1,9 +1,10 @@
 import traceback
 from datetime import datetime
-from logging import DEBUG, FATAL, ERROR, WARNING, INFO, NOTSET
+from logging import CRITICAL, DEBUG, FATAL, ERROR, WARNING, INFO, NOTSET
 
 from injector import inject
 
+from ..base import ILogger
 from ..console import ConsoleLogger
 from ...models import LogData
 from ....configuration.models.application import ApplicationConfig
@@ -13,7 +14,7 @@ from ....dependency import IScoped
 from ....utils.utils import Utils
 
 
-class SqlLogger(IScoped):
+class SqlLogger(IScoped, ILogger):
     @inject
     def __init__(self,
                  application_config: ApplicationConfig,
@@ -69,6 +70,11 @@ class SqlLogger(IScoped):
         message += f"Error: {exc}"
         self.logger_method(ERROR, message, job_id)
 
+
+    #######################################################################################
+    def critical(self, message, job_id):
+        self.logger_method(CRITICAL, message, job_id)
+        
     #######################################################################################
     def fatal(self, message, job_id=None):
         self.logger_method(FATAL, message, job_id)
